/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.doris.kafka.connector.writer;

public class LoadConstants {
    public static final String DORIS_DELETE_SIGN = "__DORIS_DELETE_SIGN__";
    public static final String DORIS_DEL_TRUE = "1";
    public static final String DORIS_DEL_FALSE = "0";

    // Special identifier, label separator used for kafka-connect sink data
    public static final String FILE_DELIM_DEFAULT = "__KC_";

    // since apache doris 2.1.0, support stream load with group commit mode.
    public static final String GROUP_COMMIT = "group_commit";
    public static final String PARTIAL_COLUMNS = "partial_columns";
}
